@@ -8,5 +8,8 @@ class MissingParameter(AlipayException):
 
 
 class ParameterValueError(AlipayException):
-	"""Raised when parameter value is incorrect
-	"""
\ No newline at end of file
+    """Raised when parameter value is incorrect"""
+    
+class TokenAuthorizationError(AlipayException):
+    '''The error occurred when getting token 
+    '''
\ No newline at end of file
